@@ -1,4 +1,4 @@
-package Pcore::Chrome v0.1.3;
+package Pcore::Chrome v0.1.4;
 
 use Pcore -dist, -const, -class;
 use Pcore::Chrome::Tab;
@@ -102,7 +102,7 @@ sub run ( $self, @args ) {
             $self->{port} = $args{port};
 
             # wait for chrome
-            $proc->{timer} = AE::timer 3, 0, sub {
+            $proc->{timer} = AE::timer $args{timeout} // 3, 0, sub {
                 delete $proc->{timer};
 
                 $cb->($self) if $cb;
@@ -184,11 +184,12 @@ Pcore::Chrome
     use Pcore::Chrome;
 
     my $chrome = Pcore::Chrome->new->run(
-        host      => '127.0.0.1',
-        port      => 9222,
-        bin       => undef,
-        headless  => 1,
-        useragent => undef,
+        host      => '127.0.0.1',     # chrome --remote-debugging-address
+        port      => 9222,            # chrome --remote-debugging-port
+        bin       => undef,           # chrome binary path
+        timeout   => 3,               # chrome startup timeout
+        headless  => 1,               # run chrome in headless mode
+        useragent => undef,           # redefine User-Agent
     );
 
 =head1 DESCRIPTION
